---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:1988-10-27;470
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=19881107&codiceRedaz=088G0533&dataVigenza=20251104
dataGU: 19881107
codiceRedaz: 088G0533
dataVigenza: 20251104
---

# Anagrafe e censimento degli italiani all'estero.

La Camera dei deputati ed il Senato della Repubblica hanno

approvato;

IL PRESIDENTE DELLA REPUBBLICA

PROMULGA la seguente legge:

## ANAGRAFI DEI CITTADINI RESIDENTI ALL'ESTERO

### Art. 1.

1. Le anagrafi dei cittadini italiani residenti all'estero (AIRE) sono tenute presso i comuni e presso il Ministero dell'interno.

2. Le anagrafi dei comuni sono costituite da schedari che raccolgono le schede individuali e le schede di famiglia eliminate dall'anagrafe della popolazione residente in dipendenza del trasferimento permanente all'estero delle persone cui esse si riferiscono, ed inoltre le schede istituite a seguito di trascrizione di atti di stato civile pervenuti dall'estero.

3. Gli ufficiali di stato civile devono comunicare all'ufficio d'anagrafe del proprio comune il contenuto degli atti dello stato civile e delle relative annotazioni che si riferiscono ai cittadini residenti all'estero.

4. L'anagrafe istituita presso il Ministero dell'interno contiene dati desunti dalle anagrafi comunali e dalle dichiarazioni rese a norma dell'articolo 6.

5. La stessa anagrafe contiene i dati anagrafici dei cittadini nati e residenti all'estero dei quali nessuno degli ascendenti e' nato nel territorio della Repubblica o vi ha mai risieduto.

6. Ai fini di cui al comma 5, l'ufficio dello stato civile di Roma comunica all'anagrafe del Ministero dell'interno il contenuto degli atti dello stato civile e delle relative annotazioni che si riferiscono ai predetti cittadini.

7. Apposita annotazione indica, per ogni cittadino incluso nell'anagrafe di cui ai commi 4 e 5, se lo stesso e' iscritto nelle liste elettorali di un comune della Repubblica.

8. Non sono iscritti nelle anagrafi di cui al presente articolo 1 i cittadini che si recano all'estero per cause di durata limitata non superiore a dodici mesi.

9. Non sono altresi' iscritti nelle stesse anagrafi:

- a) i cittadini che si recano all'estero per l'esercizio di occupazioni stagionali; ((5))
- b) i dipendenti di ruolo dello Stato in servizio all'estero e le persone con essi conviventi, i quali siano stati notificati alle autorita' locali ai sensi delle convenzioni di Vienna sulle relazioni diplomatiche e sulle relazioni consolari, rispettivamente del 1961 e del 1963, ratificate con legge 9 agosto 1967, n. 804.

10. Il supporto tecnico per la tenuta e l'aggiornamento dell'anagrafe di cui al comma 4 e' costituito dal centro elettronico della Direzione centrale per i servizi elettorali.

11. Ad uno o piu' funzionari del Ministero dell'interno, con qualifica funzionale non inferiore alla settima, sono attribuiti i poteri e i doveri dell'ufficiale di anagrafe.

12. Gli atti delle anagrafi di cui al presente articolo sono atti pubblici.

-------------- AGGIORNAMENTO (5) Il D.Lgs. 13 aprile 2017, n. 64 ha disposto (con l'art. 38, comma 1) che "A decorrere dal primo giorno dell'anno scolastico successivo all'entrata in vigore del presente decreto legislativo, all'articolo 1, comma 9, lettera a), della legge 27 ottobre 1988, n. 470, dopo la parola: «stagionale» sono aggiunte le seguenti «, nonche' dirigenti scolastici, docenti e personale amministrativo della scuola collocati fuori ruolo ed inviati all'estero nell'ambito di attivita' scolastiche fuori dal territorio nazionale»".

### Art. 2.

1. L'iscrizione nelle anagrafi degli italiani residenti all'estero viene effettuata:

- a) per trasferimento della residenza da un comune italiano all'estero, dichiarato o accertato a norma del regolamento di esecuzione della legge 24 dicembre 1954, n. 1228, sull'ordinamento delle anagrafi della popolazione residente, approvato con decreto del Presidente della Repubblica 31 gennaio 1958, n. 136, e successive modificazioni;
- b) per trasferimento dall'AIRE di altro comune o dall'anagrafe di cui al comma 4 dell'articolo 1, quando l'interessato ne faccia domanda, avendo membri del proprio nucleo familiare iscritti nell'AIRE o nell'anagrafe della popolazione residente del comune;
- c) a seguito della registrazione dell'atto di nascita pervenuto ai sensi degli articoli 51 e 52 del regio decreto 9 luglio 1939, n. 1238, e dell'articolo 73, ultimo comma, del decreto del Presidente della Repubblica 5 gennaio 1967, n. 200;
- d) per acquisizione della cittadinanza italiana da parte di persona residente all'estero;
- e) per esistenza di cittadino all'estero giudizialmente dichiarata.

2. L'ufficiale di anagrafe annota sulle schede individuali l'indirizzo all'estero comunicato dall'interessato o comunque accertato.

### Art. 3.

1. Nelle anagrafi degli italiani residenti all'estero devono essere registrate le mutazioni relative alle posizioni anagrafiche conseguenti:

- a) alle dichiarazioni, rese dagli interessati per se' o per persone sulle quali esercitano la potesta' o tutela, concernenti i trasferimenti di residenza o di abitazione che hanno avuto luogo all'estero;
- b) alle comunicazioni di stato civile;
- c) alle dichiarazioni rese dagli interessati concernenti il cambiamento della qualifica professionale e del titolo di studio.

### Art. 4.

1. La cancellazione dalle anagrafi degli italiani residenti all'estero viene effettuata:

- a) per iscrizione nell'anagrafe della popolazione residente a seguito di trasferimento dall'estero;
- b) per immigrazione dall'estero in altro comune della Repubblica, segnalata a norma del secondo comma dell'articolo 14 del decreto del Presidente della Repubblica 31 gennaio 1958, n. 136;
- c) per morte, compresa la morte presunta giudizialmente dichiarata;
- d) per irreperibilita' presunta, salvo prova contraria: 1) trascorsi cento anni dalla nascita; 2) dopo due rilevazioni censuarie consecutive concluse con esito negativo; 3) quando risulti inesistente, tanto nel comune di provenienza quanto nell'AIRE, indirizzo all'estero; 4) quando risulti dal ritorno per mancato recapito della cartolina avviso, spedita ai sensi dell'articolo 6 della legge 7 febbraio 1979, n. 40, in occasione delle due ultime consultazioni che si siano tenute con un intervallo non inferiore ad un anno, esclusa l'elezione del Parlamento europeo limitatamente ai cittadini residenti nei Paesi dell'Unione europea nonche' le consultazioni referendarie locali;
- e) per perdita della cittadinanza;
- f) per trasferimento nell'AIRE di altro comune.

### Art. 5.

1. Gli ufficiali di anagrafe che eseguono le iscrizioni, le mutazioni e le cancellazioni di cui agli articoli 2, 3 e 4 devono darne comunicazione entro quarantotto ore al Ministero dell'interno che le comunica entro sessanta giorni dalla ricezione ai competenti uffici consolari.

### Art. 6.

1. I cittadini italiani che trasferiscono la loro residenza da un comune italiano all'estero devono farne dichiarazione all'ufficio consolare della circoscrizione di immigrazione entro novanta giorni dalla immigrazione.

2. I cittadini italiani che risiedono all'estero alla data dell'entrata in vigore della presente legge devono dichiarare la loro residenza al competente ufficio consolare entro un anno dalla predetta data.

3. I cittadini italiani residenti all'estero che cambiano la residenza o l'abitazione devono farne dichiarazione entro novanta giorni all'ufficio consolare nella cui circoscrizione si trova la nuova residenza o la nuova abitazione.

4. Le dichiarazioni rese dagli interessati devono specificare i componenti della famiglia di cittadinanza italiana ai quali la dichiarazione stessa si riferisce e sono accompagnate da documentazione comprovante la residenza nella circoscrizione consolare.

5. Le rappresentanze diplomatiche e gli uffici consolari provvedono comunque a svolgere ogni opportuna azione intesa a promuovere la presentazione delle dichiarazioni di cui al presente articolo, anche sulla base delle comunicazioni di cui all'articolo 5, ed avvalendosi, per quanto possibile, della collaborazione delle pubbliche autorita' locali, per ottenere la segnalazione dei nominativi dei cittadini italiani residenti nelle rispettive circoscrizioni, e dei relativi recapiti.

6. Le notizie recate dalle dichiarazioni sono registrate dagli uffici consolari interessati negli schedari istituiti a norma dell'articolo 67 del decreto del Presidente della Repubblica 5 gennaio 1967, n. 200. Scaduti i termini per la presentazione delle dichiarazioni di cui al presente articolo, gli uffici consolari provvedono ad iscrivere d'ufficio nei predetti schedari i cittadini italiani che non abbiano presentato le dichiarazioni, ma dei quali gli uffici consolari abbiano conoscenza, in base ai dati in loro possesso.

7. Una copia autentica della dichiarazione o, in mancanza di questa, l'iscrizione d'ufficio e' trasmessa entro centottanta giorni dall'ufficio consolare al Ministero dell'interno per le registrazioni di competenza e per le successive, immediate comunicazioni al comune italiano competente.

8. Altra copia autentica della dichiarazione e' trasmessa all'ufficio consolare della circoscrizione di provenienza.

9. La richiesta agli uffici consolari, da parte dei cittadini italiani residenti all'estero, di atti, documenti e certificati deve essere accompagnata, qualora non siano gia' state rese, dalle dichiarazioni di cui al presente articolo. In mancanza di tali dichiarazioni gli uffici consolari corrisponderanno alla richiesta, provvedendo contestualmente alla iscrizione d'ufficio a norma del comma 6.

9-bis. Gli effetti della dichiarazione resa all'ufficio consolare, ai sensi dei commi 1 e 3, hanno decorrenza dalla data di presentazione della stessa, qualora non sia stata gia' resa la dichiarazione di trasferimento di residenza all'estero presso il comune di ultima residenza, a norma della vigente legislazione anagrafica. (6)

((

9-ter. Le pubbliche amministrazioni di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, all'articolo 1, comma 2, della legge 31 dicembre 2009, n. 196, e all'articolo 19, comma 2, della legge 28 dicembre 2005, n. 262, che, nell'esercizio delle funzioni, acquisiscono elementi rilevanti che indicano la residenza di fatto all'estero da parte del cittadino italiano, li comunicano al comune di iscrizione anagrafica e all'ufficio consolare competente per territorio rispettivamente per i provvedimenti di competenza, inclusi quelli di cui all'articolo 11 della legge 24 dicembre 1954, n. 1228.

9-quater. Il comune comunica le iscrizioni e cancellazioni d'ufficio effettuate nell'Anagrafe degli italiani residenti all'estero all'Agenzia delle entrate per i controlli fiscali di competenza))

-------------- AGGIORNAMENTO (6) Il D.L. 25 marzo 2019, n. 22, convertito con modificazioni dalla L. 20 maggio 2019, n. 41, ha disposto (con l'art. 16, comma 3) che "Le dichiarazioni di cui al presente comma presentate anteriormente alla data di entrata in vigore del presente decreto e non ancora ricevute dall'ufficiale di anagrafe hanno decorrenza dalla medesima data".

### Art. 7.

1. Sulla base delle risultanze dell'anagrafe dei cittadini italiani residenti all'estero e con l'osservanza delle disposizioni degli articoli da 29 a 31 del decreto del Presidente della Repubblica 31 gennaio 1958, n. 136, spetta agli ufficiali di anagrafe dei comuni ed a quelli di cui all'articolo 1, comma 11, il rilascio dei seguenti certificati:

- a) certificato di stato di famiglia;
- b) certificato di residenza attestante che il richiedente, in precedenza iscritto nell'anagrafe dei residenti nel comune da certa data, risulta attualmente nell'anagrafe degli italiani residenti all'estero, con decorrenza dalla data di cancellazione dall'anagrafe della popolazione residente per trasferimento all'estero, ovvero dalla data di iscrizione nell'anagrafe dei residenti all'estero a seguito di trascrizione di atto di stato civile.

## RILEVAZIONE DEI CITTADINI ITALIANI ALL'ESTERO

### Art. 8.

1. La rilevazione dei cittadini italiani all'estero ha luogo contemporaneamente al censimento dei cittadini residenti in Italia. (2)

(( 2. La rilevazione dei cittadini italiani all'estero si svolge ricavando i dati personali disponibili citati all'articolo 10 dagli schedari consolari di cui all'articolo 67 dei decreto del Presidente della Repubblica 5 gennaio 1967, n. 200 ))

3. Il Ministero degli affari esteri sovraintende a tutte le operazioni relative alla rilevazione adottando i provvedimenti necessari per il loro regolare e tempestivo svolgimento; promuove, inoltre, nelle forme ritenute piu' efficaci, idonea attivita' di informazione e pubblicita' in merito alla rilevazione stessa. ------------------ AGGIORNAMENTO (2) Il D.L. 3 agosto 2001, n. 312, convertito con modificazioni dalla L. 1 ottobre 2001, n. 358, ha disposto (con l'art. 1, comma 1) che, in deroga a quanto stabilito dal comma 1 del presente articolo, la seconda rilevazione dei cittadini italiani all'estero, di cui al citato articolo 8, e' fissata in data 21 marzo 2003.

### Art. 9.

1. Oggetto della rilevazione dei cittadini all'estero sono, in ciascuna circoscrizione consolare, i cittadini italiani residenti e i cittadini italiani temporaneamente presenti.

2. Sono residenti nella circoscrizione consolare i cittadini italiani che, alla data della rilevazione, hanno la dimora abituale nella circoscrizione stessa, anche se ne sono temporaneamente assenti per motivi che non comportano trasferimento di residenza, secondo le norme della presente legge e del regolamento di esecuzione della legge 24 dicembre 1954, n. 1228, sull'ordinamento delle anagrafi della popolazione residente, approvato con decreto del Presidente della Repubblica 31 gennaio 1958, n. 136, e successive modificazioni.

3. Sono temporaneamente presenti nella circoscrizione consolare i cittadini italiani che vi si trovano per uno dei motivi di cui ai commi 8 e 9 dell'articolo 1 e che hanno la residenza in Italia.

### Art. 10.

1. Per le singole persone costituenti la popolazione residente, la rilevazione concerne le fondamentali notizie di stato civile ed anagrafico, il comune italiano di ultima residenza e di origine e l'iscrizione nelle liste elettorali.

2. Per le persone temporaneamente presenti nella circoscrizione la rilevazione concerne notizie di stato civile ed anagrafico, il luogo di residenza, il motivo della temporanea presenza e l'iscrizione nelle liste elettorali.

3. La rilevazione ha inoltre per oggetto notizie concernenti il grado di istruzione dei cittadini residenti all'estero, le notizie professionali ed altre di carattere socio-economico.

### Art. 11.

(( ARTICOLO ABROGATO DALLA L. 27 MAGGIO 2002, N. 104 ))

### Art. 12.

1. Il capo dell'ufficio consolare e' responsabile del buon andamento delle operazioni della rilevazione nell'ambito della circoscrizione consolare e riferisce al Ministero degli affari esteri in ordine al regolare svolgimento delle operazioni stesse.

### Art. 13.

1. Le rappresentanze diplomatiche e gli uffici consolari provvedono a svolgere ogni opportuna azione intesa ad ottenere la segnalazione da parte delle pubbliche autorita' locali dei nominativi e del recapito dei cittadini italiani che si trovano nella loro circoscrizione.

2. (( COMMA ABROGATO DALLA L. 27 MAGGIO 2002, N. 104 )).

3. (( COMMA ABROGATO DALLA L. 27 MAGGIO 2002, N. 104 )).

### Art. 14.

((

1. Sulla base dei dati della rilevazione, le rappresentanze diplomatico-consolari, dopo aver aggiornato gli schedari di cui all'articolo 67 del decreto del Presidente della Repubblica 5 gennaio 1967, n. 200, ne trasmettono in via informatica i dati al Ministero degli affari esteri, che li trasmette al Ministero dell'interno Centro elettronico della direzione centrale per i servizi elettorali, per l'aggiornamento dell'AIRE e per la memorizzazione dei dati raccolti.

2. Il Ministero dell'interno trasmette i dati di cui al comma 1 ai comuni, i quali provvedono entro i successivi sessanta giorni all'aggiornamento delle rispettive anagrafi, fatta salva la previsione di cui al comma 3.

3. Con decreto del Ministro dell'interno, sentito il Ministro degli affari esteri, il termine di cui al comma 2 puo' essere prorogato per il comune di Roma fino ad un massimo di ulteriori centottanta giorni ))

### Art. 15.

(( ARTICOLO ABROGATO DALLA L. 27 MAGGIO 2002, N. 104 ))

## DISPOSIZIONI FINALI

### Art. 16.

1. Agli effetti dell'applicazione delle norme della presente legge, l'espressione "uffici consolari" indica gli uffici consolari di prima categoria.

2. Le relative circoscrizioni comprendono quelle degli uffici consolari ad essi aggregati con decreto del Ministro degli affari esteri.

3. Nei Paesi in cui non esistono gli uffici consolari di prima categoria sopra indicati, le funzioni previste dalla presente legge sono svolte dalle ambasciate, previa consultazione degli organismi locali rappresentativi della comunita' italiana.

### Art. 17.

1. Al fine di potenziare i servizi connessi con gli schedari ed i registri di cui al decreto del Presidente della Repubblica 5 gennaio 1967, n. 200, nonche' di agevolare le operazioni di registrazione e rilevazione previste dalla presente legge, il Ministero degli affari esteri, le rappresentanze diplomatiche e gli uffici consolari saranno dotati di adeguati strumenti ed attrezzature informatiche inclusi i programmi di base ed applicativi nonche' di sistemi elettronici e telematici per la raccolta, elaborazione e trasmissione dei dati.

2. Per la fase di avvio delle operazioni previste al comma precedente, il Ministero degli affari esteri e' autorizzato ad assumere, con le modalita' di cui al decreto del Presidente della Repubblica 5 gennaio 1967, n. 18, ed alla legge 13 agosto 1980, n. 462, anche in deroga a quanto previsto dall'articolo 3 di detta legge ed eventuali altri divieti di assunzione, impiegati con contratto temporaneo nei limiti di un contingente non superiore a cento unita' da assegnarsi alle rappresentanze diplomatiche o uffici consolari di prima categoria, in relazione alla consistenza delle comunita' italiane residenti nelle rispettive circoscrizioni.

3. (( COMMA ABROGATO DAL D. LGS. 7 APRILE 2000, N. 103 )).

4. Le assunzioni del personale previste dal presente articolo possono essere effettuate a partire dall'entrata in vigore della presente legge.

5. La rilevazione degli italiani all'estero potra' essere effettuata in collaborazione con l'Istituto centrale di statistica.

### Art. 18.

1. Entro sei mesi dalla data di entrata in vigore della presente legge, con decreto del Presidente della Repubblica su proposta del Ministro degli affari esteri, di concerto con i Ministri del tesoro, dell'interno e di grazia e giustizia, sentito l'Istituto centrale di statistica, e' emanato il regolamento per l'esecuzione della legge stessa e saranno dettate le norme per la prima formazione e per la tenuta degli schedari dei cittadini residenti all'estero.

### Art. 19.

1. All'onere derivante dalla presente legge, valutato in lire 5 miliardi per l'anno 1988 e lire 10 miliardi annui per i successivi esercizi finanziari, si provvede mediante corrispondente riduzione dello stanziamento iscritto, ai fini del bilancio triennale 1988-1990, al capitolo 6856 dello stato di previsione per il Ministero del tesoro per il 1988, utilizzando l'apposito accantonamento.

2. Per gli adempimenti di competenza del Ministero dell'interno, ivi compresi quelli dell'articolo 14, terzo comma, e' riservata nell'ambito degli stanziamenti di cui al comma 1 la somma di 2 miliardi da ripartire negli esercizi 1988, 1989, 1990.

3. Le somme di cui al presente articolo non impegnate o non erogate nell'anno di competenza, possono essere utilizzate per gli stessi fini nell'arco di due esercizi finanziari immediatamente successivi.

4. Il Ministro del tesoro e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

### Art. 20.

1. Sono abrogate le disposizioni di legge in contrasto o comunque incompatibili con la presente legge.

### Art. 21.

1. La presente legge entra in vigore il giorno successivo a quello della sua pubblicazione nella Gazzetta Ufficiale della Repubblica italiana.

